@@ -1,6 +1,6 @@
 /* Opie (s/key) support for FTP.
    Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Free Software Foundation, Inc.
+   2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 
 This file is part of GNU Wget.
 
@@ -28,14 +28,13 @@ Corresponding Source for a non-source form of such a combination
 shall include the source code for the parts of OpenSSL used as well
 as that of the covered work.  */
 
-#include <config.h>
+#include "wget.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "wget.h"
-#include "gen-md5.h"
+#include "md5.h"
 #include "ftp.h"
 
 /* Dictionary for integer-word translations.  Available in appendix D
@@ -2158,7 +2157,7 @@ btoe (char *store, const unsigned char *c)
   memcpy (store, &Wp[extract (cp, 55, 11)][0], 4);
   store[4] = '\0';              /* make sure the string is terminated */
 
-  DEBUGP (("wrote `%s' to STORE\n", store_beg));
+  DEBUGP (("wrote %s to STORE\n", quote (store_beg)));
   return store_beg;
 }
 
@@ -2197,22 +2196,22 @@ skey_response (int sequence, const char *seed, const char *pass)
      the terminating \0.  24+5+1 == 30  */
   static char english[30];
 
-  ALLOCA_MD5_CONTEXT (md5_ctx);
+  struct md5_ctx ctx;
   uint32_t checksum[4];
 
-  gen_md5_init (md5_ctx);
-  gen_md5_update ((const unsigned char *)seed, strlen(seed), md5_ctx);
-  gen_md5_update ((const unsigned char *)pass, strlen(pass), md5_ctx);
-  gen_md5_finish (md5_ctx, (unsigned char *)checksum);
+  md5_init_ctx (&ctx);
+  md5_process_bytes ((const unsigned char *) seed, strlen (seed), &ctx);
+  md5_process_bytes ((const unsigned char *) pass, strlen (pass), &ctx);
+  md5_finish_ctx (&ctx, (unsigned char *) checksum);
   checksum[0] ^= checksum[2];
   checksum[1] ^= checksum[3];
   memcpy (key, checksum, 8);
 
   while (sequence-- > 0)
     {
-      gen_md5_init (md5_ctx);
-      gen_md5_update ((unsigned char *) key, 8, md5_ctx);
-      gen_md5_finish (md5_ctx, (unsigned char *) checksum);
+      md5_init_ctx (&ctx);
+      md5_process_bytes ((unsigned char *) key, 8, &ctx);
+      md5_finish_ctx (&ctx, (unsigned char *) checksum);
       checksum[0] ^= checksum[2];
       checksum[1] ^= checksum[3];
       memcpy (key, checksum, 8);
